@@ -1,18 +1,67 @@
 package Config::Simple::Conf;
-# @@COPYRIGHT@@
+# Copyright 2016 (C) Colin Faber <cfaber@fpsn.net>
+# Licensed under the terms of perl itself.
 
 use strict;
 # Version number - cvs automagically updated.
-our $VERSION = $1 if('$Revision: 1.4 $' =~ /: ([\d\.]+)/);
+our $VERSION = $1 if('$Revision: 1.5 $' =~ /: ([\d\.]+)/);
 
 # Revision - cvs automagically updated
-our $REVISION = '$Id: Conf.pm,v 1.4 2016/04/24 23:09:20 cfaber Exp $';
+our $REVISION = '$Id: Conf.pm,v 1.5 2016/04/25 17:26:38 cfaber Exp $';
 
 # Ruckus Global Version Number
 
 =head1 NAME
 
-Config::Simple::Conf - an extremely fast, light weight configuration file parser with caching
+Config::Simple::Conf - A fast and lightweight configuration file handler
+
+=head1 DESCRIPTION
+
+The idea behind Config::Simple::Conf came from various INI style parsers I've used in the past. In general these have worked well with the exception of lack of complex configuration handling.
+
+Config::Simple for example fails to account for common cases which are extremely useful in any configuration file. These include useful handling of duplicate keys (currently Config::Simple blows them away without any notice), and second, internal macros.
+
+In many of my usage cases I want something like your standard .INI file format, with the above mentioned exceptions.
+
+	# Define a configuration section
+	[core section]
+
+	# Define an entry in core section
+	path = /root/to/my/stuff
+
+	# Define a new configuration file section
+	[section name]
+
+	# Define an entry list and use the value from another section to complete
+	# the configuration
+	path = [core section: path]/abc
+	path = [core section: path]/xyz
+
+Such a configuration would allow me to do two things, establish a core path argument, which is then used in other sections, and have a section with multiple duplicate entires as a list.
+
+An example of the code here would look something like:
+
+	#!/usr/bin/perl
+
+	use strict;
+	use Config::Simple::Conf;
+
+	my $conf = Config::Simple::Conf->new('/path/to/my.conf');
+
+	print "My root is: " . $conf->value('core section', 'path') . "\n";
+	print "My section paths are:\n";
+
+	for($conf->value('section name', 'path')){
+		print "\t$_\n";
+	}
+
+With the resulting output looking something like:
+
+	My root is: /root/to/my/stuff
+	My section paths are:
+		/root/to/my/stuff/abc
+		/root/to/my/stuff/xyz
+
 
 =head1 SYNOPSIS
 
